@@ -45,6 +45,15 @@ impl NmPdu {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -165,6 +174,15 @@ impl NPdu {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -251,6 +269,15 @@ impl DcmIPdu {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -397,6 +424,15 @@ impl GeneralPurposePdu {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -539,6 +575,15 @@ impl GeneralPurposeIPdu {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -686,6 +731,15 @@ impl MultiplexedIPdu {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -760,14 +814,13 @@ impl MultiplexedIPdu {
         }
     }
 
-    // TODO: enable iterator once the fixed version of autosar-data-abstraction is published
-    // fn dynamic_part_alternatives(&self) -> DynamicPartAlternativesIterator {
-    //     DynamicPartAlternativesIterator::new(
-    //         self.0
-    //             .dynamic_part_alternatives()
-    //             .map(DynamicPartAlternative),
-    //     )
-    // }
+    fn dynamic_part_alternatives(&self) -> DynamicPartAlternativesIterator {
+        DynamicPartAlternativesIterator::new(
+            self.0
+                .dynamic_part_alternatives()
+                .map(DynamicPartAlternative),
+        )
+    }
 
     // --------- AbstractIPdu methods ---------
 
@@ -790,7 +843,7 @@ impl MultiplexedIPdu {
 
 //##################################################################
 
-// iterator_wrapper!(DynamicPartAlternativesIterator, DynamicPartAlternative);
+iterator_wrapper!(DynamicPartAlternativesIterator, DynamicPartAlternative);
 
 //##################################################################
 
@@ -817,6 +870,15 @@ impl DynamicPartAlternative {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[getter]
     fn element(&self) -> Element {
         Element(self.0.element().clone())
@@ -829,6 +891,81 @@ impl DynamicPartAlternative {
 
 //##################################################################
 
+/// user-defined PDU
+#[pyclass(
+    frozen,
+    eq,
+    module = "autosar_data._autosar_data._abstraction._communication"
+)]
+#[derive(Clone, PartialEq)]
+pub(crate) struct UserDefinedPdu(
+    pub(crate) autosar_data_abstraction::communication::UserDefinedPdu,
+);
+
+#[pymethods]
+impl UserDefinedPdu {
+    #[new]
+    fn new(element: &Element) -> PyResult<Self> {
+        match autosar_data_abstraction::communication::UserDefinedPdu::try_from(element.0.clone()) {
+            Ok(value) => Ok(Self(value)),
+            Err(e) => Err(AutosarAbstractionError::new_err(e.to_string())),
+        }
+    }
+
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
+    #[setter]
+    fn set_name(&self, name: &str) -> PyResult<()> {
+        self.0.set_name(name).map_err(abstraction_err_to_pyerr)
+    }
+
+    #[getter]
+    fn name(&self) -> Option<String> {
+        self.0.name()
+    }
+
+    #[getter]
+    fn element(&self) -> Element {
+        Element(self.0.element().clone())
+    }
+
+    fn __repr__(&self) -> String {
+        format!("{:#?}", self.0)
+    }
+
+    // --------- AbstractPdu methods ---------
+
+    /// set the length of this PDU
+    #[setter]
+    fn set_length(&self, length: u32) -> PyResult<()> {
+        self.0.set_length(length).map_err(abstraction_err_to_pyerr)
+    }
+
+    /// get the length of this PDU
+    #[getter]
+    fn length(&self) -> Option<u32> {
+        self.0.length()
+    }
+
+    /// iterate over the `PduTriggerings` that trigger this PDU
+    fn pdu_triggerings(&self) -> Vec<PduTriggering> {
+        self.0
+            .pdu_triggerings()
+            .into_iter()
+            .map(PduTriggering)
+            .collect()
+    }
+}
+
+//##################################################################
+
 /// a `PduTriggering` triggers a PDU in a frame or ethernet connection
 #[pyclass(
     frozen,
@@ -848,6 +985,15 @@ impl PduTriggering {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -947,6 +1093,15 @@ impl IPduPort {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -1069,6 +1224,9 @@ pub(crate) fn pdu_to_pyany(
         autosar_data_abstraction::communication::Pdu::MultiplexedIPdu(multiplexed_ipdu) => {
             MultiplexedIPdu(multiplexed_ipdu.clone()).into_py_any(py)
         }
+        autosar_data_abstraction::communication::Pdu::UserDefinedPdu(user_defined_pdu) => {
+            UserDefinedPdu(user_defined_pdu.clone()).into_py_any(py)
+        }
     })
 }
 
