@@ -3,15 +3,16 @@ use crate::{
     abstraction::{
         ArPackage, AutosarAbstractionError, EcuInstance, abstraction_err_to_pyerr,
         communication::{
-            CanCluster, CanFrame, CanTpConfig, ContainerIPdu, ContainerIPduHeaderType, DcmIPdu,
-            DiagPduType, DoIpTpConfig, EthernetCluster, EventGroupControlType, FlexrayArTpConfig,
-            FlexrayCluster, FlexrayClusterSettings, FlexrayFrame, FlexrayTpConfig,
-            GeneralPurposeIPdu, GeneralPurposeIPduCategory, GeneralPurposePdu,
-            GeneralPurposePduCategory, ISignal, ISignalGroup, ISignalIPdu, LinCluster,
-            LinEventTriggeredFrame, LinSporadicFrame, LinUnconditionalFrame, MultiplexedIPdu, NPdu,
-            NmConfig, NmPdu, RxAcceptContainedIPdu, SecureCommunicationProps, SecuredIPdu,
-            ServiceInstanceCollectionSet, SoAdRoutingGroup, SocketConnectionIpduIdentifierSet,
-            SomeipTpConfig, SystemSignal, SystemSignalGroup,
+            CanCluster, CanFrame, CanTpConfig, CommunicationDirection, ContainerIPdu,
+            ContainerIPduHeaderType, DcmIPdu, DiagPduType, DoIpTpConfig, EthernetCluster,
+            EventGroupControlType, FlexrayArTpConfig, FlexrayCluster, FlexrayClusterSettings,
+            FlexrayFrame, FlexrayTpConfig, GeneralPurposeIPdu, GeneralPurposeIPduCategory,
+            GeneralPurposePdu, GeneralPurposePduCategory, ISignal, ISignalGroup, ISignalIPdu,
+            ISignalIPduGroup, LinCluster, LinEventTriggeredFrame, LinSporadicFrame,
+            LinUnconditionalFrame, MultiplexedIPdu, NPdu, NmConfig, NmPdu, RxAcceptContainedIPdu,
+            SecureCommunicationProps, SecuredIPdu, ServiceInstanceCollectionSet, SoAdRoutingGroup,
+            SocketConnectionIpduIdentifierSet, SomeipTpConfig, SystemSignal, SystemSignalGroup,
+            UserDefinedPdu,
         },
         datatype::SwBaseType,
         software_component::{CompositionSwComponentType, RootSwCompositionPrototype},
@@ -45,6 +46,15 @@ impl System {
         }
     }
 
+    #[pyo3(signature = (/, *, deep = false))]
+    #[pyo3(text_signature = "(self, /, *, deep: bool = false)")]
+    fn remove(&self, deep: bool) -> PyResult<()> {
+        self.clone()
+            .0
+            .remove(deep)
+            .map_err(abstraction_err_to_pyerr)
+    }
+
     #[setter]
     fn set_name(&self, name: &str) -> PyResult<()> {
         self.0.set_name(name).map_err(abstraction_err_to_pyerr)
@@ -252,6 +262,66 @@ impl System {
         }
     }
 
+    /// create a new [`LinEventTriggeredFrame`]
+    ///
+    /// This new frame needs to be linked to a `LinPhysicalChannel`
+    #[pyo3(signature = (name, package, byte_length, /))]
+    #[pyo3(text_signature = "(self, name: str, package: ArPackage, byte_length: int, /)")]
+    fn create_lin_event_triggered_frame(
+        &self,
+        name: &str,
+        package: &ArPackage,
+        byte_length: u64,
+    ) -> PyResult<LinEventTriggeredFrame> {
+        match self
+            .0
+            .create_lin_event_triggered_frame(name, &package.0, byte_length)
+        {
+            Ok(frame) => Ok(LinEventTriggeredFrame(frame)),
+            Err(error) => Err(AutosarAbstractionError::new_err(error.to_string())),
+        }
+    }
+
+    /// create a new [`LinSporadicFrame`]
+    ///
+    /// This new frame needs to be linked to a `LinPhysicalChannel`
+    #[pyo3(signature = (name, package, byte_length, /))]
+    #[pyo3(text_signature = "(self, name: str, package: ArPackage, byte_length: int, /)")]
+    fn create_lin_sporadic_frame(
+        &self,
+        name: &str,
+        package: &ArPackage,
+        byte_length: u64,
+    ) -> PyResult<LinSporadicFrame> {
+        match self
+            .0
+            .create_lin_sporadic_frame(name, &package.0, byte_length)
+        {
+            Ok(frame) => Ok(LinSporadicFrame(frame)),
+            Err(error) => Err(AutosarAbstractionError::new_err(error.to_string())),
+        }
+    }
+
+    /// create a new [`LinUnconditionalFrame`]
+    ///
+    /// This new frame needs to be linked to a `LinPhysicalChannel`
+    #[pyo3(signature = (name, package, byte_length, /))]
+    #[pyo3(text_signature = "(self, name: str, package: ArPackage, byte_length: int, /)")]
+    fn create_lin_unconditional_frame(
+        &self,
+        name: &str,
+        package: &ArPackage,
+        byte_length: u64,
+    ) -> PyResult<LinUnconditionalFrame> {
+        match self
+            .0
+            .create_lin_unconditional_frame(name, &package.0, byte_length)
+        {
+            Ok(frame) => Ok(LinUnconditionalFrame(frame)),
+            Err(error) => Err(AutosarAbstractionError::new_err(error.to_string())),
+        }
+    }
+
     /// iterate over all Frames in the System
     fn frames(&self) -> FrameIterator {
         use autosar_data_abstraction::communication as comm;
@@ -501,6 +571,21 @@ impl System {
         }
     }
 
+    /// create a [`UserDefinedPdu`] in the [`System`]
+    #[pyo3(signature = (name, package, length, /))]
+    #[pyo3(text_signature = "(self, name: str, package: ArPackage, length: int, /)")]
+    fn create_user_defined_pdu(
+        &self,
+        name: &str,
+        package: &ArPackage,
+        length: u32,
+    ) -> PyResult<UserDefinedPdu> {
+        match self.0.create_user_defined_pdu(name, &package.0, length) {
+            Ok(ipdu) => Ok(UserDefinedPdu(ipdu)),
+            Err(error) => Err(AutosarAbstractionError::new_err(error.to_string())),
+        }
+    }
+
     /// iterate over all PDUs in the System
     ///
     /// This iterator returns all PDUs that are connected to the System using a FibexElementRef.
@@ -532,10 +617,34 @@ impl System {
             }
             autosar_data_abstraction::communication::Pdu::MultiplexedIPdu(pdu) => {
                 Python::attach(|py| MultiplexedIPdu(pdu).into_py_any(py).ok())
+            }
+            autosar_data_abstraction::communication::Pdu::UserDefinedPdu(pdu) => {
+                Python::attach(|py| UserDefinedPdu(pdu).into_py_any(py).ok())
             } //_ => None,
         }))
     }
 
+    /// create a new `ISignalIPduGroup` in the System
+    pub fn create_isignal_ipdu_group(
+        &self,
+        name: &str,
+        package: &ArPackage,
+        communication_direction: CommunicationDirection,
+    ) -> PyResult<ISignalIPduGroup> {
+        match self
+            .0
+            .create_isignal_ipdu_group(name, &package.0, communication_direction.into())
+        {
+            Ok(set) => Ok(ISignalIPduGroup(set)),
+            Err(error) => Err(AutosarAbstractionError::new_err(error.to_string())),
+        }
+    }
+
+    /// iterate over all ISSignalIPduGroups in the system
+    fn isignal_ipdu_groups(&self) -> ISignalIPduGroupIterator {
+        ISignalIPduGroupIterator::new(self.0.isignal_ipdu_groups().map(ISignalIPduGroup))
+    }
+
     /// Create a `SocketConnectionIpduIdentifierSet` in the SYSTEM
     ///
     /// `SocketConnectionIpduIdentifierSet` are part of the new ethernet modeling that was introduced in Autosar 4.5.0 (`AUTOSAR_00048`).
@@ -796,6 +905,7 @@ iterator_wrapper!(FrameIterator, Py<PyAny>, "Union[CanFrame, FlexrayFrame]");
 iterator_wrapper!(ISignalIterator, ISignal);
 iterator_wrapper!(ISignalGroupIterator, ISignalGroup);
 iterator_wrapper!(PduIterator, Py<PyAny>, "Pdu");
+iterator_wrapper!(ISignalIPduGroupIterator, ISignalIPduGroup);
 
 //#########################################################
 
